from unittest import TestCase
import os
from osirisl1services.readlevel1 import Orbit


class TestOrbit(TestCase):
    def test_types(self):
        with self.assertRaises(TypeError):
            Orbit('6432')

    def test_orbit_too_small(self):
        with self.assertWarns(UserWarning):
            Orbit(3712)

    def test_as_hex(self):
        self.assertEqual(Orbit(6431).as_hex(), '191f')
        self.assertEqual(Orbit(6432).as_hex(), '1920')

    def test_l1_folder(self):
        self.assertEqual(Orbit(8999).l1_folder(), os.path.join(os.environ['ODINORBITDIR'], 'disk1', '08900'))
        self.assertEqual(Orbit(9000).l1_folder(), os.path.join(os.environ['ODINORBITDIR'], 'disk2', '09000'))
        self.assertEqual(Orbit(18999).l1_folder(), os.path.join(os.environ['ODINORBITDIR'], 'disk2', '18900'))
        self.assertEqual(Orbit(19000).l1_folder(), os.path.join(os.environ['ODINORBITDIR'], 'disk3', '19000'))
        self.assertEqual(Orbit(60000).l1_folder(), os.path.join(os.environ['ODINORBITDIR'], 'disk3', '60000'))

    def test_l1_attitude_filename(self):
        self.assertEqual(Orbit(6432).l1_attitude_filename,
                         os.path.join(os.environ['ODINORBITDIR'], 'disk1', '06400', 'so1_1920.oat'))

    def test_l1_housekeeping_filename(self):
        self.assertEqual(Orbit(6432).l1_housekeeping_filename,
                         os.path.join(os.environ['ODINORBITDIR'], 'disk1', '06400', 'sh1_1920.hk1'))

    def test_l1_spectrograph_filename(self):
        self.assertEqual(Orbit(6432).l1_spectrograph_filename,
                         os.path.join(os.environ['ODINORBITDIR'], 'disk1', '06400', 'ss1_1920.os1'))

    def test_l1_radiation_hit_filename(self):
        self.assertEqual(Orbit(6432).l1_radiation_hit_filename,
                         os.path.join(os.environ['ODINORBITDIR'], 'disk1', '06400', 'sp1_1920.txt'))

    def test_l1_ir_filename(self):
        self.assertEqual(Orbit(6432).l1_ir_filename,
                         os.path.join(os.environ['ODINORBITDIR'], 'disk1', '06400', 'si1_1920.ir1'))

    def test_l1b_ir_filename(self):
        self.assertEqual(Orbit(6432).l1b_ir_filename,
                         os.path.join(os.environ['ODINORBITDIR'], 'disk1', '06400', 'si1b1920.ir1'))
